<?php
#Author: Bernd Klenk(klenkes) info@klenk-services.de

function smarty_cms_function_simple_osmmap($params, &$smarty)
{
  $mapid = isset($params['mapid']) ? $params['mapid'] : 'map';
  $lat = isset($params['lat']) ? $params['lat'] : '';
  $lng = isset($params['lng']) ? $params['lng'] : '';
  $zoom = isset($params['zoom']) ? $params['zoom'] : '14';
  $popuptext = isset($params['popuptext']) ? $params['popuptext'] : '';
  $showpopup = isset($params['showpopup']) ? $params['showpopup'] : '1';

  // Na, das knnte man aber besser machen... ;-)
  if (!isset($params['lat']) || !isset($params['lng'])){echo 'Achtung: Es fehlen die Koordinaten';}

  // CSS und JS sollte nicht hier eingefgt werden. Besser raus und in den HEAD(Metafeld) der Page setzen!
  echo '
  <link rel="stylesheet" href="http://cdn.leafletjs.com/leaflet-0.7.2/leaflet.css" />
  <script src="http://cdn.leafletjs.com/leaflet-0.7.2/leaflet.js"></script>
  <style>
    #'.$mapid.' {width:100%; height: 300px;}
  </style>
  
  <div id="'.$mapid.'"></div>
  
  <script type="text/javascript">
    var map;
    
    function initmap() {
    map = new L.Map(\''.$mapid.'\');
    
    // Layer erstellen mit z.B. hier Openstreetmap
    var osmUrl=\'http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png\';
    var osmAttrib=\'Kartendaten durch &copy; <a href="http://openstreetmap.org">OpenStreetMap</a>\';
    var osm = new L.TileLayer(osmUrl, {minZoom: 8, maxZoom: 18, attribution: osmAttrib});// evtl. minZoom und maxZoom anpassen
    
    // Koordinaten und weitere Attribute setzen
    map.setView(new L.LatLng('.$lat.','.$lng.'),'.$zoom.');
    map.addLayer(osm);
    var marker = L.marker(['.$lat.','.$lng.']).addTo(map);
  ';
  
  if (isset($params['popuptext']) && $showpopup == '1'){$show = ".openPopup()";}
  
  if (isset($params['popuptext'])){
    echo '  marker.bindPopup("'.$popuptext.'")'.$show.';';
    }
  
  echo '
  }
    initmap();
  </script>
  ';

}// function


function smarty_cms_help_function_simple_osmmap() {
?>
<style>
.pagecontainer h3 {font-size:1.3em; margin:20px 0 5px 0;}
.pagecontainer h4 {color:#555; font-size:1.0em; margin:0;}
table {border:1px solid #666; border-collapse:collapse; margin-bottom:15px;}
td, th {border:1px solid #666; padding:7px;}
</style>

<h3>Was macht dieser Tag?</h3>
<p>
  Er f&uuml;gt eine einfache Karte/Map ala Googlemap ein, aber mit <strong>Openstreetmap</strong> und <strong>Leaflet</strong> als Javascript, womit es wesentlich kleiner und leichter f&uuml;r die Website ist.<br>
  JS und CSS je nach Kompression und Ladeart manchmal nur 50kb, die Karte manchmal nur 10 Requests, und damit um ein Vielfaches schneller als eine Googlemap.
</p>
<p><br>
  Da das Plugin zum einfachen Einsatz gedacht ist, erfolgt <strong>keine</strong> &Uuml;bersetzung von Adressen in Geokoordinaten via Google oder Nominatim, sondern die direkte Angabe von 
  <br> - LAT (Latitude - Breitengrad) und 
  <br> - LNG (Longitude - L&auml;ngengrad)
  <br>als Parameter in der Form von lat="45.12345" usw...<br>
  <strong>Die Koordinaten eines Ortes holt man sich ganz leicht hier:</strong> <a href="http://mygeoposition.com/" target="new">MyGeoPosition</a>
</p>

<h3>Welche Parameter sind m&ouml;glich:</h3>
<table border=0 cellpadding=0 cellspacing=0>
<tr><th>Option</th><th>Parameter</th><th>Beschreibung</th><th>Default</th></tr>
<tr><td>required</td><td><code>mapid</code></td><td> ID der Map f&uuml;r JS und CSS</td><td>map</td></tr>
<tr><td>required</td><td><code>lat</code></td><td> Koordinate Latitude(Breitengrad)</td><td>-</td></tr>
<tr><td>required</td><td><code>lng</code></td><td> Koordinate Longitude(L&auml;ngengrad)</td><td>-</td></tr>
<tr><td>optional</td><td><code>zoom</code></td><td> Initialer Zoomwert der Map</td><td>14</td></tr>
<tr><td>optional</td><td><code>showpopup</code></td><td> Soll das Popup sofort gezeigt werden, oder erst auf einen Klick auf den Marker?<br>0 f&uuml;r Nein oder 1 f&uuml;r Ja(Defaultwert)</td><td>1</td></tr>
<tr><td>optional</td><td><code>popuptext</code></td><td> Text der in das Popup &uuml;ber den Marker soll.<br>Ist der Parameter leer, wird nur der Marker gezeigt.<br>Umlaute funktionieren prima und auch HTML. HTML wird allerdings vom TINY umgewandelt.</td><td>-</td></tr>
</table>

<h3>Beispiel Einbau:</h3>
<pre>Alle Parameter:
{simple_osmmap mapid="mymap" lat="48.65607" lng="10.27923" zoom="16" popuptext="Hier wohne ich.<br>Ich bin ein Landei!" showpopup="0"}
Minimal:
{simple_osmmap lat="48.65607" lng="10.2792300"}
</pre>
<h3>Tipp:</h3>
<p>Besser w&auml;re es diese Aufrufe aus der Plugindatei rauszunehmen und im HEAD der Seite einzf&uuml;gen.</p>
<pre>
&lt;link rel=&quot;stylesheet&quot; href=&quot;http://cdn.leafletjs.com/leaflet-0.7.2/leaflet.css&quot; /&gt;
&lt;script src=&quot;http://cdn.leafletjs.com/leaflet-0.7.2/leaflet.js&quot;&gt;&lt;/script&gt;
</pre>
<p>Das Selbe gilt f&uuml;r das CSS des MAP-Divs. Besser in's Stylesheet packen.</p>
<pre>
&lt;style&gt;
  #mapid {width:100%; height: 300px;}
&lt;/style&gt;
</pre>

<h3>Quellen und weitere Infos:</h3>
<p>
<a href="http://leafletjs.com/" target="new">Leaflet</a> - Open-Source JavaScript Library for Mobile-Friendly Interactive Maps<br>
<a href="http://switch2osm.org/using-tiles/getting-started-with-leaflet/" target="new">Switch2OSM</a> - Make the switch to OpenStreetMap "und" Getting startet with Leaflet
</p>

<h3>ToDo:</h3>
<ul>
  <li>W&auml;re sch&ouml;n, wenn CSS und JS atomatisch in den HEAD gesetzt werden k&ouml;nnten</li>
  <li>Fehlerbehandlung</li>
</ul>

<?php
}
function smarty_cms_about_function_simple_osmmap() {
   ?>
   <p>Author: Bernd Klenk(Klenkes) | info@klenk-services.de </p>
   <p>Version: 0.5</p>

  <h3>ToDo:</h3>
  <ul>
  <li>W&auml;re sch&ouml;n, wenn CSS und JS atomatisch in den HEAD gesetzt werden k&ouml;nnten</li>
  <li>Fehlerbehandlung</li>
  </ul>
  
   <?php
}
?>
